@@ -2,7 +2,7 @@ use serde::{Deserialize, Serialize};
 use serde_json::Value;
 use std::collections::HashMap;
 
-fn is_false(v: &bool) -> bool {
+pub fn is_false(v: &bool) -> bool {
     !(*v)
 }
 
