@@ -5,21 +5,22 @@ use crate::id_lists_adapter::{IdList, IdListsUpdateListener};
 use crate::observability::observability_client_adapter::{MetricType, ObservabilityEvent};
 use crate::observability::ops_stats::{OpsStatsForInstance, OPS_STATS};
 use crate::observability::sdk_errors_observer::ErrorBoundaryEvent;
-use crate::spec_types::{SpecsResponse, SpecsResponseFull, SpecsResponseNoUpdates};
+use crate::specs_response::spec_types::{SpecsResponseFull, SpecsResponseNoUpdates};
+use crate::specs_response::spec_types_encoded::DecodedSpecsResponse;
+use crate::utils::maybe_trim_malloc;
 use crate::{
     log_d, log_e, log_error_to_statsig_and_console, SpecsInfo, SpecsSource, SpecsUpdate,
     SpecsUpdateListener, StatsigErr, StatsigRuntime,
 };
 use chrono::Utc;
-use serde::Serialize;
 use std::collections::HashMap;
 use std::sync::{Arc, RwLock};
 
-#[derive(Clone, Serialize)]
 pub struct SpecStoreData {
     pub source: SpecsSource,
     pub time_received_at: Option<u64>,
     pub values: SpecsResponseFull,
+    pub next_values: Option<SpecsResponseFull>,
     pub decompression_dict: Option<DictionaryDecoder>,
     pub id_lists: HashMap<String, IdList>,
 }
@@ -47,7 +48,8 @@ impl SpecStore {
         SpecStore {
             hashed_sdk_key,
             data: Arc::new(RwLock::new(SpecStoreData {
-                values: SpecsResponseFull::blank(),
+                values: SpecsResponseFull::default(),
+                next_values: Some(SpecsResponseFull::default()),
                 time_received_at: None,
                 source: SpecsSource::Uninitialized,
                 decompression_dict: None,
@@ -63,52 +65,63 @@ impl SpecStore {
     pub fn set_source(&self, source: SpecsSource) {
         if let Ok(mut mut_values) = self.data.write() {
             mut_values.source = source;
-            log_d!(TAG, "SpecStore - Source Changed ({:?})", mut_values.source);
+            log_d!(TAG, "Source Changed ({:?})", mut_values.source);
         }
     }
 
-    pub fn get_current_values(&self) -> Option<SpecStoreData> {
-        let cloned = self.data.read().ok()?.clone();
-        Some(cloned)
+    pub fn get_current_values(&self) -> Option<SpecsResponseFull> {
+        let data = self.data.read().ok()?;
+        let json = serde_json::to_string(&data.values).ok()?;
+        serde_json::from_str::<SpecsResponseFull>(&json).ok()
     }
 
-    pub fn set_values(&self, values: SpecsUpdate) -> Result<(), StatsigErr> {
-        let dcs = match self.parse_specs_response(&values)? {
-            SpecsResponse::Full(full) => full,
-            SpecsResponse::NoUpdates(_) => {
-                self.ops_stats_log_no_update(values.source);
-                return Ok(());
-            }
-        };
-
-        if self.are_current_values_newer(&dcs) {
-            return Ok(());
-        }
-
-        let mut mut_values = match self.data.write() {
-            Ok(mut_values) => mut_values,
+    pub fn set_values(&self, specs_update: SpecsUpdate) -> Result<(), StatsigErr> {
+        let (mut next_values, decompression_dict) = match self.data.write() {
+            Ok(mut data) => (
+                data.next_values.take().unwrap_or_default(),
+                data.decompression_dict.clone(),
+            ),
             Err(e) => {
                 log_e!(TAG, "Failed to acquire write lock: {}", e);
                 return Err(StatsigErr::LockFailure(e.to_string()));
             }
         };
 
-        self.try_update_global_configs(&dcs);
+        let decompression_dict =
+            match self.parse_specs_response(&specs_update, &mut next_values, decompression_dict) {
+                Ok(Some(full)) => full,
+                Ok(None) => {
+                    self.ops_stats_log_no_update(specs_update.source);
+                    return Ok(());
+                }
+                Err(e) => {
+                    return Err(e);
+                }
+            };
+
+        if self.are_current_values_newer(&next_values) {
+            return Ok(());
+        }
+
+        self.try_update_global_configs(&next_values);
 
         let now = Utc::now().timestamp_millis() as u64;
-        let prev_source = mut_values.source.clone();
+        let (prev_source, prev_lcut, curr_values_time) =
+            self.swap_current_with_next(next_values, &specs_update, decompression_dict, now)?;
 
-        mut_values.values = *dcs;
-        mut_values.time_received_at = Some(now);
-        mut_values.source = values.source.clone();
-
-        self.try_update_data_store(&mut_values.source, values.data, now);
-        self.ops_stats_log_config_propogation_diff(
-            mut_values.values.time,
-            &mut_values.source,
+        self.try_update_data_store(&specs_update.source, specs_update.data, now);
+        self.ops_stats_log_config_propagation_diff(
+            curr_values_time,
+            prev_lcut,
+            &specs_update.source,
             &prev_source,
         );
 
+        // Glibc requested more memory than needed when deserializing a big json blob
+        // And memory allocator fails to return it.
+        // To prevent service from OOMing, manually unused heap memory.
+        maybe_trim_malloc();
+
         Ok(())
     }
 }
@@ -116,65 +129,76 @@ impl SpecStore {
 // -------------------------------------------------------------------------------------------- [Private Functions]
 
 impl SpecStore {
-    fn parse_specs_response(&self, values: &SpecsUpdate) -> Result<SpecsResponse, StatsigErr> {
-        let parsed = match serde_json::from_str::<SpecsResponse>(&values.data) {
-            Ok(response) => response,
+    fn parse_specs_response(
+        &self,
+        values: &SpecsUpdate,
+        next_values: &mut SpecsResponseFull,
+        decompression_dict: Option<DictionaryDecoder>,
+    ) -> Result<Option<Option<DictionaryDecoder>>, StatsigErr> {
+        let full_update_decoder_result = DecodedSpecsResponse::from_slice(
+            &values.data,
+            next_values,
+            decompression_dict.as_ref(),
+        );
+
+        if let Ok(result) = full_update_decoder_result {
+            if next_values.has_updates {
+                return Ok(Some(result));
+            }
+
+            return Ok(None);
+        }
+
+        let mut next_no_updates = SpecsResponseNoUpdates { has_updates: false };
+        let no_updates_decoder_result = DecodedSpecsResponse::from_slice(
+            &values.data,
+            &mut next_no_updates,
+            decompression_dict.as_ref(),
+        );
+
+        if no_updates_decoder_result.is_ok() && !next_no_updates.has_updates {
+            return Ok(None);
+        }
+
+        let error = full_update_decoder_result.err().map_or_else(
+            || StatsigErr::JsonParseError("SpecsResponse".to_string(), "Unknown error".to_string()),
+            |e| StatsigErr::JsonParseError("SpecsResponse".to_string(), e.to_string()),
+        );
+
+        log_error_to_statsig_and_console!(self.ops_stats, TAG, error);
+        Err(error)
+    }
+
+    fn swap_current_with_next(
+        &self,
+        next_values: SpecsResponseFull,
+        specs_update: &SpecsUpdate,
+        decompression_dict: Option<DictionaryDecoder>,
+        now: u64,
+    ) -> Result<(SpecsSource, u64, u64), StatsigErr> {
+        match self.data.write() {
+            Ok(mut data) => {
+                let prev_source = std::mem::replace(&mut data.source, specs_update.source.clone());
+                let prev_lcut = data.values.time;
+
+                let mut temp = next_values;
+                std::mem::swap(&mut data.values, &mut temp);
+                data.next_values = Some(temp);
+
+                data.time_received_at = Some(now);
+                data.decompression_dict = decompression_dict;
+
+                Ok((prev_source, prev_lcut, data.values.time))
+            }
             Err(e) => {
-                log_error_to_statsig_and_console!(
-                    self.ops_stats,
-                    TAG,
-                    "{:?}, {:?}",
-                    e,
-                    values.source
-                );
-                return Err(StatsigErr::JsonParseError(
-                    "SpecsResponse".to_string(),
-                    e.to_string(),
-                ));
-            }
-        };
-
-        match parsed {
-            SpecsResponse::Full(full) => {
-                if !full.has_updates {
-                    return Ok(SpecsResponse::NoUpdates(SpecsResponseNoUpdates {
-                        has_updates: false,
-                    }));
-                }
-
-                log_d!(
-                    TAG,
-                    "SpecStore Full Update: {} - [gates({}), configs({}), layers({})]",
-                    full.time,
-                    full.feature_gates.len(),
-                    full.dynamic_configs.len(),
-                    full.layer_configs.len(),
-                );
-
-                Ok(SpecsResponse::Full(full))
-            }
-            SpecsResponse::NoUpdates(no_updates) => {
-                if no_updates.has_updates {
-                    log_error_to_statsig_and_console!(
-                        self.ops_stats,
-                        TAG,
-                        "Empty response with has_updates = true {:?}",
-                        values.source
-                    );
-
-                    return Err(StatsigErr::JsonParseError(
-                        "SpecsResponse".to_owned(),
-                        "Parse failure. 'has_update' is true, but failed to deserialize to response format 'dcs-v2'".to_owned(),
-                    ));
-                }
-
-                Ok(SpecsResponse::NoUpdates(no_updates))
+                log_e!(TAG, "Failed to acquire write lock: {}", e);
+                Err(StatsigErr::LockFailure(e.to_string()))
             }
         }
     }
 
     fn ops_stats_log_no_update(&self, source: SpecsSource) {
-        log_d!(TAG, "SpecStore - No Updates");
+        log_d!(TAG, "No Updates");
         self.ops_stats.log(ObservabilityEvent::new_event(
             MetricType::Increment,
             "config_no_update".to_string(),
@@ -183,14 +207,15 @@ impl SpecStore {
         ));
     }
 
-    fn ops_stats_log_config_propogation_diff(
+    fn ops_stats_log_config_propagation_diff(
         &self,
         lcut: u64,
+        prev_lcut: u64,
         source: &SpecsSource,
         prev_source: &SpecsSource,
     ) {
         let delay = Utc::now().timestamp_millis() as u64 - lcut;
-        log_d!(TAG, "SpecStore - Updated ({:?})", source);
+        log_d!(TAG, "Updated ({:?})", source);
 
         if *prev_source == SpecsSource::Uninitialized || *prev_source == SpecsSource::Loading {
             return;
@@ -198,9 +223,13 @@ impl SpecStore {
 
         self.ops_stats.log(ObservabilityEvent::new_event(
             MetricType::Dist,
-            "config_propogation_diff".to_string(),
+            "config_propagation_diff".to_string(),
             delay as f64,
-            Some(HashMap::from([("source".to_string(), source.to_string())])),
+            Some(HashMap::from([
+                ("source".to_string(), source.to_string()),
+                ("lcut".to_string(), lcut.to_string()),
+                ("prev_lcut".to_string(), prev_lcut.to_string()),
+            ])),
         ));
     }
 
@@ -215,7 +244,7 @@ impl SpecStore {
         }
     }
 
-    fn try_update_data_store(&self, source: &SpecsSource, data: String, now: u64) {
+    fn try_update_data_store(&self, source: &SpecsSource, data: Vec<u8>, now: u64) {
         if *source != SpecsSource::Network {
             return;
         }
@@ -226,40 +255,53 @@ impl SpecStore {
         };
 
         let hashed_key = self.hashed_sdk_key.clone();
+
         self.statsig_runtime.spawn(
             "spec_store_update_data_store",
             move |_shutdown_notif| async move {
+                let data_string = match String::from_utf8(data) {
+                    Ok(s) => s,
+                    Err(e) => {
+                        log_e!(TAG, "Failed to convert data to string: {}", e);
+                        return;
+                    }
+                };
+
                 let _ = data_store
-                    .set(&get_data_adapter_dcs_key(&hashed_key), &data, Some(now))
+                    .set(
+                        &get_data_adapter_dcs_key(&hashed_key),
+                        &data_string,
+                        Some(now),
+                    )
                     .await;
             },
         );
     }
 
-    fn are_current_values_newer(&self, dcs: &SpecsResponseFull) -> bool {
-        let guard = match self.data.read() {
-            Ok(guard) => guard,
+    fn are_current_values_newer(&self, next_values: &SpecsResponseFull) -> bool {
+        let data = match self.data.read() {
+            Ok(data) => data,
             Err(e) => {
                 log_e!(TAG, "Failed to acquire read lock: {}", e);
                 return false;
             }
         };
 
-        let curr_values = &guard.values;
+        let curr_values = &data.values;
         let curr_checksum = curr_values.checksum.as_deref().unwrap_or_default();
-        let new_checksum = dcs.checksum.as_deref().unwrap_or_default();
+        let new_checksum = next_values.checksum.as_deref().unwrap_or_default();
 
-        let cached_time_is_newer = curr_values.time > 0 && curr_values.time > dcs.time;
+        let cached_time_is_newer = curr_values.time > 0 && curr_values.time > next_values.time;
         let checksums_match = !curr_checksum.is_empty() && curr_checksum == new_checksum;
 
         if cached_time_is_newer || checksums_match {
             log_d!(
-                    TAG,
-                    "SpecStore - Received values for [time: {}, checksum: {}], but currently has values for [time: {}, checksum: {}]. Ignoring values.",
-                    dcs.time,
-                    new_checksum,
-                    curr_values.time,
-                    curr_checksum,
+                TAG,
+                "Received values for [time: {}, checksum: {}], but currently has values for [time: {}, checksum: {}]. Ignoring values.",
+                next_values.time,
+                new_checksum,
+                curr_values.time,
+                curr_checksum,
                 );
             return true;
         }
@@ -346,28 +388,3 @@ impl IdListsUpdateListener for SpecStore {
         }
     }
 }
-
-impl SpecsResponseFull {
-    fn blank() -> Self {
-        SpecsResponseFull {
-            feature_gates: Default::default(),
-            dynamic_configs: Default::default(),
-            layer_configs: Default::default(),
-            condition_map: Default::default(),
-            experiment_to_layer: Default::default(),
-            has_updates: true,
-            time: 0,
-            checksum: None,
-            default_environment: None,
-            app_id: None,
-            sdk_keys_to_app_ids: None,
-            hashed_sdk_keys_to_app_ids: None,
-            diagnostics: None,
-            param_stores: None,
-            sdk_configs: None,
-            cmab_configs: None,
-            overrides: None,
-            override_rules: None,
-        }
-    }
-}
