@@ -4,8 +4,9 @@ use crate::evaluation::evaluation_types::{
 };
 use crate::event_logging::event_logger::EventLogger;
 use crate::statsig_types::{DynamicConfig, Experiment, FeatureGate, Layer};
-use crate::statsig_user_internal::StatsigUserInternal;
+use crate::user::StatsigUserLoggable;
 use crate::SamplingProcessor;
+
 use serde_json::Value;
 use std::collections::HashMap;
 use std::sync::Weak;
@@ -34,7 +35,7 @@ pub fn make_feature_gate(
     }
 }
 
-fn extract_from_experiment_evaluation(
+pub fn extract_from_experiment_evaluation(
     evaluation: &Option<ExperimentEvaluation>,
 ) -> (HashMap<String, Value>, String, String, Option<String>) {
     match &evaluation {
@@ -96,7 +97,7 @@ pub fn make_experiment(
 
 #[allow(clippy::too_many_arguments)]
 pub fn make_layer(
-    user: &StatsigUserInternal,
+    user: StatsigUserLoggable,
     name: &str,
     evaluation: Option<LayerEvaluation>,
     details: EvaluationDetails,
@@ -106,25 +107,27 @@ pub fn make_layer(
     sampling_processor: Option<Weak<SamplingProcessor>>,
     override_config_name: Option<String>,
 ) -> Layer {
-    let (value, rule_id, group_name, allocated_experiment_name) = match &evaluation {
+    let (value, rule_id, group_name, allocated_experiment_name, id_type) = match &evaluation {
         Some(e) => (
             e.value.clone(),
             e.base.rule_id.clone(),
             e.group_name.clone(),
             e.allocated_experiment_name.clone(),
+            e.id_type.clone(),
         ),
-        None => (HashMap::new(), "default".into(), None, None),
+        None => (HashMap::new(), "default".into(), None, None, "".into()),
     };
 
     Layer {
         name: name.to_string(),
         rule_id,
+        id_type,
         details: details.clone(),
         group_name,
         allocated_experiment_name,
         __value: value,
         __evaluation: evaluation,
-        __user: user.clone(),
+        __user: user,
         __event_logger_ptr: event_logger_ptr,
         __version: version,
         __disable_exposure: disable_exposure,
